%global appliance_root /opt/rh/cfme-appliance
%global app_root /var/www/miq/vmdb

%global pgscl_prefix rh-postgresql95-

Name:     cfme-appliance
Version:  5.10.5.1
Release:  1%{?dist}
Summary:  CloudForms Management Engine appliance configuration

Group:    Applications/Internet
License:  Unknown
URL:      https://github.com/ManageIQ/manageiq-appliance

Source0:  %{name}-%{version}.tar.gz

Requires: cfme-appliance-common = %{version}

Requires: %{pgscl_prefix}postgresql-server
Requires: %{pgscl_prefix}postgresql-pglogical >= 2.1.0-4
Requires: %{pgscl_prefix}repmgr >= 4.0.6

Requires: ansible-tower-setup >= 3.4.3
Requires: ansible-tower-server >= 3.4.3

Requires: httpd
Requires: lvm2
Requires: memcached

# NTP
Requires: chrony

# External Authentication
Requires: sssd >= 1.11.6
Requires: sssd-dbus >= 1.11.6

# External Authentication - IPA
Requires: c-ares >= 1.7.0
Requires: ipa-admintools >= 3.0.0
Requires: ipa-client >= 3.0.0
Requires: mod_intercept_form_submit >= 0.9.7
Requires: mod_auth_kerb >= 5.4
Requires: mod_auth_gssapi
Requires: mod_authnz_pam >= 0.9.2
Requires: mod_lookup_identity >= 0.9.2
Requires: mod_ssl

# External Authentication - Active Directory
Requires: adcli
Requires: oddjob
Requires: oddjob-mkhomedir
Requires: realmd
Requires: samba-common
Requires: samba-common-tools

# External Authentication - SAML
Requires: mod_auth_mellon

# External Authentication - OpenID-Connect
Requires: mod_auth_openidc

# SCAP
Requires: openscap
Requires: scap-security-guide

# Software Update
Requires: yum-utils

%description
CloudForms Management Engine Appliance

%package common
Summary:  CloudForms Management Engine appliance common
Requires: cfme = %{version}
Requires: nmap-ncat
# For log rotate
Requires: cronie
Requires: logrotate
# External Authentication - LDAP
Requires: openldap-clients

%description common
CloudForms Management Engine appliance common

%package tools
Summary:  CloudForms Management Engine appliance tools
Requires: less
Requires: nano
Requires: screen
Requires: smem
Requires: tree
Requires: unzip
Requires: vim-enhanced
Requires: wget

%description tools
CloudForms Management Engine appliance tools

%prep
%setup -q

%pretrans -p <lua>
if posix.access('/bin/evmserver.sh', 'x') then
  local pid = posix.fork ()
  if ( pid == -1 ) then
    print ("The fork failed.")
  elseif ( pid == 0 ) then
    posix.exec('/bin/evmserver.sh', 'update_stop')
  else
    posix.wait(pid)
  end
end

%posttrans -p <lua>
if posix.access('/bin/evmserver.sh', 'x') then
  local pid = posix.fork ()
  if ( pid == -1 ) then
    print ("The fork failed.")
  elseif ( pid == 0 ) then
    posix.exec('/bin/evmserver.sh', 'update_start')
  else
    posix.wait(pid)
  end
end

%install

%{__mkdir} -p %{buildroot}%{appliance_root}
%{__cp} -r * %{buildroot}%{appliance_root}
%{__mkdir} -p %{buildroot}/etc/httpd/conf.d
%{__mkdir} -p %{buildroot}%{app_root}/log/apache

#symlink some executables
%{__mkdir} -p %{buildroot}/%{_bindir}
pushd ./LINK/usr/bin
  for filename in `ls`; do
    ln -s %{appliance_root}/LINK/usr/bin/$filename %{buildroot}/%{_bindir}/$filename
  done
popd

#symlink some configuration files
pushd ./LINK/etc
  for dirname in `ls`; do
    pushd ./$dirname
      %{__mkdir} -p %{buildroot}/%{_sysconfdir}/$dirname
      for filename in `ls`; do
        ln -s %{appliance_root}/LINK/etc/$dirname/$filename %{buildroot}/%{_sysconfdir}/$dirname/$filename
      done
    popd
  done
popd

%{__mkdir} -p %{buildroot}/root
pushd ./LINK/root
  ln -s %{appliance_root}/LINK/root/.ansible.cfg %{buildroot}/root/.ansible.cfg
  ln -s %{appliance_root}/LINK/root/.bowerrc %{buildroot}/root/.bowerrc
popd

pushd ./LINK
  ln -s %{appliance_root}/LINK/.toprc %{buildroot}/.toprc
popd

#symlink license file for prince PDF
%{__mkdir} -p %{buildroot}%{_prefix}/lib/prince/license
ln -s %{appliance_root}/LINK/usr/lib/prince/license/license.dat %{buildroot}%{_prefix}/lib/prince/license/license.dat

#copy all files/directories below COPY
%{__cp} -r ./COPY/* %{buildroot}/

%post
#Ensure pre-5.6 external auth configuration files are renamed if exist.
#Also, delete cfme-* files generated by evm service
pushd %{_sysconfdir}/httpd/conf.d
  prefix_before="cfme-"
  prefix_after="manageiq-"
  files_to_rename="external-auth.conf remote-user.conf"

  for file_to_rename in ${files_to_rename}
  do
    name_before=${prefix_before}${file_to_rename}
    name_after=${prefix_after}${file_to_rename}
    if [ ! -f ${name_after} -a -f ${name_before} ]
    then
      %{__mv} ${name_before} ${name_after}
    fi
  done

  extauth_conf="manageiq-external-auth.conf"
  if [ -f ${extauth_conf} ]
  then
    sed -i s:/dashboard/authenticate:/dashboard/external_authenticate: ${extauth_conf}
  fi

  rm -f cfme-balancer-{ui,websocket,ws}.{conf,conf_old}
  rm -f cfme-redirects-{ui,websocket,ws}
popd

#motd is owned by system
%{__cp} -f %{_sysconfdir}/motd.manageiq %{_sysconfdir}/motd

# Delete crontab entry and hourly cron file added for DB maintenance
sed -i '/periodic_vacuum_full_tables/d' %{_sysconfdir}/crontab

pg_maintenance_cron=%{_sysconfdir}/cron.hourly/miq-pg-maintenance-hourly.cron
if [ -f ${pg_maintenance_cron} ]; then rm -f ${pg_maintenance_cron}; fi

%post common
%post tools

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%{_sysconfdir}/motd.manageiq

%files common
%defattr(-,root,root,-)
/.toprc
/root/.ansible.cfg
/root/.bowerrc
%{appliance_root}
%{app_root}/log/apache
%{_bindir}/cloud_ds_check.sh
%{_bindir}/evm*
%{_bindir}/fix_auth
%{_bindir}/generate_miq_server_cert.sh
%{_bindir}/miq*
%{_bindir}/normalize_userid_to_upn
%{_bindir}/pg_inspector_server.sh
%{_prefix}/lib/prince/license/license.dat
%{_prefix}/lib/systemd/system/cloud-ds-check.service
%{_prefix}/lib/systemd/system/evm*
%{_prefix}/lib/systemd/system/miq*
%{_sbindir}/ifup-local
%{_sysconfdir}/cloud/cloud.cfg.d/10_miq_*.cfg
%{_sysconfdir}/cron.hourly/miq*
%{_sysconfdir}/cron.hourly/pg-inpsector-server-hourly.cron
%{_sysconfdir}/default/evm*
%{_sysconfdir}/httpd/conf.d/manageiq-*
%{_sysconfdir}/issue.template
%{_sysconfdir}/logrotate.d/miq_logs.conf
%{_sysconfdir}/manageiq/postgresql.conf.d/01_miq_overrides.conf
%{_sysconfdir}/profile.d/evm.sh
%{_sysconfdir}/sudoers.d/repmgr
%{_sysconfdir}/systemd/system/rh-postgresql95-repmgr.service.d/config_file.conf

%files tools

%changelog
* Tue May 28 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.5.1-1
- 5.10.5.1-1 build

* Tue May 21 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.5.0-1
- 5.10.5.0-1 build

* Thu May 09 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.4.3-1
- 5.10.4.3-1 build

* Wed May 08 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.4.2-1
- 5.10.4.2-1 build

* Tue Apr 30 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.4.1-1
- 5.10.4.1-1 build

* Wed Apr 24 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.4.0-1
- 5.10.4.0-1 build

* Mon Apr 15 2019 John Prause <jprause@redhat.com> - 5.10.3.3-1
- 5.10.3.3-1 build

* Wed Apr 10 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.3.2-1
- 5.10.3.2-1 build

* Mon Apr 08 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.3.1-1
- 5.10.3.1-1 build

* Tue Apr 02 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.3.0-1
- 5.10.3.0-1 build

* Tue Mar 19 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.2.2-1
- 5.10.2.2-1 build

* Mon Mar 18 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.2.1-1
- 5.10.2.1-1 build

* Mon Mar 11 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.2.0-1
- 5.10.2.0-1 build

* Tue Feb 19 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.1.2-1
- 5.10.1.2-1 build

* Tue Feb 12 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.1.1-1
- 5.10.1.1-1 build

* Wed Feb 06 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.1.0-1
- 5.10.1.0-1 build

* Tue Jan 29 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.33-1
- 5.10.0.33-1 build

* Tue Jan 15 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.32-1
- 5.10.0.32-1 build

* Tue Jan 08 2019 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.31-1
- 5.10.0.31-1 build

* Tue Dec 18 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.30-1
- 5.10.0.30-1 build

* Tue Dec 11 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.29-1
- 5.10.0.29-1 build

* Tue Dec 04 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.28-1
- 5.10.0.28-1 build

* Wed Nov 28 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.27-1
- 5.10.0.27-1 build

* Tue Nov 27 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.26-1
- 5.10.0.26-1 build

* Tue Nov 20 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.25-1
- 5.10.0.25-1 build

* Tue Nov 13 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.24-1
- 5.10.0.24-1 build

* Tue Nov 06 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.23-1
- 5.10.0.23-1 build

* Tue Oct 30 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.22-1
- 5.10.0.22-1 build

* Tue Oct 23 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.21-1
- 5.10.0.21-1 build

* Tue Oct 16 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.20-1
- 5.10.0.20-1 build

* Tue Oct 09 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.19-1
- 5.10.0.19-1 build

* Wed Oct 03 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.18-1
- 5.10.0.18-1 build

* Thu Sep 27 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.17-1
- 5.10.0.17-1 build

* Wed Sep 19 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.16-1
- 5.10.0.16-1 build

* Fri Sep 14 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.15-1
- 5.10.0.15-1 build

* Fri Aug 31 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.14-1
- 5.10.0.14-1 build

* Wed Aug 22 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.12-1
- 5.10.0.12-1 build

* Thu Aug 16 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.11-1
- 5.10.0.11-1 build

* Tue Aug 14 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.10-1
- 5.10.0.10-1 build

* Wed Aug 01 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.8-1
- 5.10.0.8-1 build

* Wed Jul 25 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.6-1
- 5.10.0.6-1 build

* Wed Jul 18 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.5-1
- 5.10.0.5-1 build

* Thu Jul 12 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.4-1
- 5.10.0.4-1 build

* Thu Jul 05 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.3-1
- 5.10.0.3-1 build

* Tue Jun 26 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.2-1
- 5.10.0.2-1 build

* Tue Jun 19 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.1-1
- 5.10.0.1-1 build

* Wed Jun 13 2018 Satoe Imaishi <simaishi@redhat.com> - 5.10.0.0-1
- 5.10.0.0-1 build

* Tue May 22 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.3.0-1
- 5.9.3.0-1 build

* Tue May 01 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.2.4-1
- 5.9.2.4-1 build

* Thu Apr 19 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.2.3-1
- 5.9.2.3-1 build

* Tue Apr 10 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.2.2-1
- 5.9.2.2-1 build

* Tue Apr 03 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.2.1-1
- 5.9.2.1-1 build

* Tue Mar 20 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.2.0-1
- 5.9.2.0-1 build

* Wed Mar 14 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.1.0-1
- 5.9.1.0-1 build

* Wed Feb 21 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.22-1
- 5.9.0.22-1 build

* Wed Feb 14 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.21-1
- 5.9.0.21-1 build

* Tue Feb 06 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.20-1
- 5.9.0.20-1 build

* Tue Jan 30 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.19-1
- 5.9.0.19-1 build

* Thu Jan 25 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.18-1
- 5.9.0.18-1 build

* Tue Jan 16 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.17-1
- 5.9.0.17-1 build

* Tue Jan 09 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.16-1
- 5.9.0.16-1 build

* Wed Jan 03 2018 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.15-1
- 5.9.0.15-1 build

* Tue Dec 19 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.14-1
- 5.9.0.14-1 build

* Tue Dec 12 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.13-1
- 5.9.0.13-1 build

* Tue Dec 05 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.12-1
- 5.9.0.12-1 build

* Mon Nov 27 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.11-1
- 5.9.0.11-1 build

* Tue Nov 21 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.10-1
- 5.9.0.10-1 build

* Wed Nov 15 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.9-1
- 5.9.0.9-1 build

* Thu Nov 09 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.8-1
- 5.9.0.8-1 build

* Tue Nov 07 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.7-1
- 5.9.0.7-1 build

* Fri Nov 03 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.6-1
- 5.9.0.6-1 build

* Wed Nov 01 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.5-1
- 5.9.0.5-1 build

* Tue Oct 24 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.4-1
- 5.9.0.4-1 build

* Tue Oct 17 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.3-1
- 5.9.0.3-1 build

* Tue Oct 10 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.2-1
- 5.9.0.2-1 build

* Wed Oct 04 2017 Satoe Imaishi <simaishi@redhat.com> - 5.9.0.1-1
- 5.9.0.1-1 build

* Thu Aug 24 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.2.0-1
- 5.8.2.0-1 build

* Tue Jul 25 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.1.5-1
- 5.8.1.5-1 build

* Fri Jul 21 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.1.4-1
- 5.8.1.4-1 build

* Thu Jul 20 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.1.3-1
- 5.8.1.3-1 build

* Wed Jul 12 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.1.2-1
- 5.8.1.2-1 build

* Tue Jul 11 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.1.1-1
- 5.8.1.1-1 build

* Fri Jun 23 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.1.0-1
- 5.8.1.0-1 build

* Thu May 25 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.17-1
- 5.8.0.17-1 build

* Mon May 22 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.16-1
- 5.8.0.16-1 build

* Wed May 17 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.15-1
- 5.8.0.15-1 build

* Tue May 09 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.14-rc3.1
- 5.8.0.14-rc3.1 build

* Tue May 02 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.13-rc2.1
- 5.8.0.13-rc2.1 build

* Tue Apr 25 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.12-rc1.1
- 5.8.0.12-rc1.1 build

* Tue Apr 18 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.11-beta2.1
- 5.8.0.11-beta2.1 build

* Tue Apr 11 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.10-beta1.1
- 5.8.0.10-beta1.1 build

* Tue Apr 04 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.9-alpha2.1
- 5.8.0.9-alpha2.1 build

* Tue Mar 28 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.8-alpha1.1
- 5.8.0.8-alpha1.1 build

* Tue Mar 21 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.7-1
- 5.8.0.7-1 build

* Wed Mar 15 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.6-1
- 5.8.0.6-1 build

* Tue Mar 14 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.5-1
- 5.8.0.5-1 build

* Tue Mar 07 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.4-1
- 5.8.0.4-1 build

* Wed Mar 01 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.3-1
- 5.8.0.3-1 build

* Thu Feb 23 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.2-1
- 5.8.0.2-1 build

* Tue Feb 14 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.1-1
- 5.8.0.1-1 build

* Wed Feb 01 2017 Satoe Imaishi <simaishi@redhat.com> - 5.8.0.0-1
- 5.8.0.0-1 build

* Mon Dec 19 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.17-1
- 5.7.0.17-1 build

* Tue Dec 13 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.16-1
- 5.7.0.16-1 build

* Tue Dec 06 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.14-rc4.1
- 5.7.0.14-rc4.1 build

* Tue Nov 29 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.13-rc3.1
- 5.7.0.13-rc3.1 build

* Wed Nov 23 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.12-rc2.1
- 5.7.0.12-rc2.1 build

* Tue Nov 15 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.11-rc1.1
- 5.7.0.11-rc1.1 build

* Wed Nov 09 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.10-beta3.1
- 5.7.0.10-beta3.1 build

* Tue Nov 01 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.9-beta2.1.1
- 5.7.0.9-beta2.1.1 build

* Tue Oct 25 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.7-beta1.1
- 5.7.0.7-beta1.1 build

* Wed Oct 19 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.6-alpha3.1
- 5.7.0.6-alpha3.1 build

* Fri Oct 14 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.5-alpha2.1
- 5.7.0.5-alpha2.1 build

* Wed Oct 05 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.4-alpha1.1
- 5.7.0.4-alpha1.1 build

* Tue Sep 27 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.3-1
- 5.7.0.3-1 build

* Wed Sep 21 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.2-1
- 5.7.0.2-1 build

* Tue Sep 13 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.1-1
- 5.7.0.1-1 build

* Tue Sep 06 2016 Satoe Imaishi <simaishi@redhat.com> - 5.7.0.0-1
- 5.7.0.0-1 build

* Wed Aug 10 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.1.2-1
- 5.6.1.2-1 build

* Wed Aug 10 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.1.1-1
- 5.6.1.1-1 build

* Tue Jul 26 2016 John Prause <jprause@redhat.com> - 5.6.1.0-1
- 5.6.1.0-1 build

* Fri Jun 24 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.13-1
- 5.6.0.13-1 build

* Tue Jun 21 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.12-1
- 5.6.0.12-1 build

* Tue Jun 14 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.11-rc2.2.1
- 5.6.0.11-rc2.2.1 build

* Tue Jun 07 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.10-rc2.1.1
- 5.6.0.10-rc2.1.1 build

* Tue May 31 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.9-rc2.1
- 5.6.0.9-rc2.1 build

* Tue May 24 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.8-rc1.1
- 5.6.0.8-rc1.1 build

* Mon May 16 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.7-beta2.6.1
- 5.6.0.7-beta2.6.1 build

* Wed May 11 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.6-beta2.5.1
- 5.6.0.6-beta2.5.1 build

* Tue May 03 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.5-beta2.4.1
- 5.6.0.5-beta2.4.1 build

* Thu Apr 21 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.4-beta2.3.1
- 5.6.0.4-beta2.3.1 build

* Wed Apr 20 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.2-beta2.1.1
- 5.6.0.2-beta2.1.1 build

* Wed Apr 13 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.1-beta2.1
- 5.6.0.1-beta2.1 build

* Tue Mar 22 2016 Satoe Imaishi <simaishi@redhat.com> - 5.6.0.0-beta1.1
- 5.6.0.0-beta1.1 build

* Wed Jan 27 2016 John Prause <jprause@redhat.com> - 5.5.2.4-1
- Building 5.5.2.4-1 - needed to skip 5.5.2.3 build

* Thu Jan 21 2016 John Prause <jprause@redhat.com> - 5.5.2.2-1
- Building 5.5.2.2-1 

* Thu Jan 14 2016 John Prause <jprause@redhat.com> - 5.5.2.1-1
- Building 5.5.2.1-1 

* Wed Dec 23 2015 John Prause <jprause@redhat.com> - 5.5.2.0-3
- Building 5.5.2.0-3 removed extra character added by mistake

* Wed Dec 23 2015 John Prause <jprause@redhat.com> - 5.5.2.0-2
- Building 5.5.2.0-2 for Requires chrony addition

* Mon Dec 21 2015 John Prause <jprause@redhat.com> - 5.5.2.0-1
- Building 5.5.2.0-1

* Tue Dec 01 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.13
- Building 5.5.0.13

* Tue Nov 24 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.12-rc2.1
- Building 5.5.0.12 rc2.1

* Tue Nov 17 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.11-rc1.1
- Building 5.5.0.11 rc1.1

* Tue Nov 10 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.10-beta2.1.1
- Building 5.5.0.10 beta2.1.1

* Mon Nov 02 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.9-beta2.1
- Building 5.5.0.9 beta2.1

* Tue Oct 27 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.8-beta1.4.1
- Building 5.5.0.8 beta1.4.1

* Wed Oct 21 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.7-beta1.3.1
- Building 5.5.0.7 beta1.3.1

* Wed Oct 14 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.6-beta1.2.1
- Building 5.5.0.6 beta1.2.1

* Wed Oct 07 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.5-beta1.1.1
- Building 5.5.0.5 beta1.1.1

* Wed Oct 07 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.4-beta1.1
- Building 5.5.0.4 beta1.1

* Tue Sep 29 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.3-alpha1.2.1
- Building 5.5.0.3 alpha1.2.1

* Wed Sep 23 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.2-alpha1.1.1
- Building 5.5.0.2 alpha1.1.1

* Tue Sep 15 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.1-alpha1.2
- Building 5.5.0.1 alpha1.2 without cloud-init

* Tue Sep 15 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.1-alpha1.1
- Building 5.5.0.1 alpha1

* Fri Sep 11 2015 Satoe Imaishi <simaishi@redhat.com> - 5.5.0.0-alpha.2
- Initial Build
